@@ -28,9 +28,13 @@ from distutils.version import LooseVersion
 from urllib.request import urlopen, urlretrieve
 
 from selenium.webdriver import Chrome as _Chrome, ChromeOptions as _ChromeOptions
+from . import v2
+from . import cdp
+from . import options
 
+ChromeOptionsV2 = v2.ChromeOptions
 logger = logging.getLogger(__name__)
-__version__ = "3.0.1"
+__version__ = "3.0.2"
 
 
 TARGET_VERSION = 0
